@@ -80,19 +80,25 @@ pub mod volga;
 #[cfg(feature = "utilities")]
 pub mod utilities;
 
+#[cfg(feature = "login-helper")]
+pub mod login_helper;
+
 /// Description of an error from the REST APIs
 #[derive(Debug, Deserialize)]
 pub struct RESTError {
+    /// Error message
     #[serde(rename = "error-message")]
-    error_message: String,
+    pub error_message: String,
+    /// Additonal error information
     #[serde(rename = "error-info")]
-    error_info: serde_json::Value,
+    pub error_info: serde_json::Value,
 }
 
 /// List of REST API error messages
 #[derive(Debug, Deserialize)]
 pub struct RESTErrorList {
-    errors: Vec<RESTError>,
+    /// Error messages
+    pub errors: Vec<RESTError>,
 }
 
 /// Error returned by client functions
@@ -424,13 +430,13 @@ impl Client {
                 responses.push(v?);
             }
 
-            if responses.len() > 1 {
-                // Convert to a JSON array
-                Ok(serde_json::Value::Array(responses))
-            } else if responses.len() == 1 {
-                Ok(responses.into_iter().next().unwrap())
-            } else {
-                Ok(serde_json::Value::Object(Default::default()))
+            match responses.len() {
+                0 => Ok(serde_json::Value::Object(Default::default())),
+                1 => Ok(responses.into_iter().next().unwrap()),
+                _ => {
+                    // Convert to a JSON array
+                    Ok(serde_json::Value::Array(responses))
+                }
             }
         } else {
             tracing::error!("POST call failed");
