@@ -9,7 +9,7 @@ use tokio_tungstenite::{client_async, tungstenite::Message as WSMessage};
 const N_IN_AUTO_MORE: usize = 5;
 
 /// Volga stream mode
-#[derive(Clone, Copy, Debug, Serialize)]
+#[derive(Clone, Copy, Debug, Deserialize, Serialize, PartialEq)]
 pub enum Mode {
     /// Consumer names has to be unique
     #[serde(rename = "exclusive")]
@@ -216,7 +216,7 @@ impl<'a> ConsumerBuilder<'a> {
 }
 
 /// Metadata on the Volga message received in 'Consumer::consume'
-#[derive(Debug, Deserialize)]
+#[derive(Debug, Serialize, Deserialize)]
 pub struct MessageMetadata {
     /// Consumer name
     pub name: String,
